@@ -1,6 +1,6 @@
 metacor <- function(cor, n, studlab,
                     ##
-                    data = NULL, subset = NULL,
+                    data = NULL, subset = NULL, exclude = NULL,
                     ##
                     sm = gs("smcor"),
                     ##
@@ -76,7 +76,7 @@ metacor <- function(cor, n, studlab,
   ##
   mf <- match.call()
   ##
-  ## Catch cor, n from data:
+  ## Catch 'cor' and 'n' from data:
   ##
   cor <- eval(mf[[match("cor", names(mf))]],
               data, enclos = sys.frame(sys.parent()))
@@ -87,7 +87,7 @@ metacor <- function(cor, n, studlab,
             data, enclos = sys.frame(sys.parent()))
   chknull(n)
   ##
-  ## Catch studlab, byvar, subset from data:
+  ## Catch 'studlab', 'byvar', 'subset' and 'exclude' from data:
   ##
   studlab <- eval(mf[[match("studlab", names(mf))]],
                   data, enclos = sys.frame(sys.parent()))
@@ -100,6 +100,10 @@ metacor <- function(cor, n, studlab,
   subset <- eval(mf[[match("subset", names(mf))]],
                  data, enclos = sys.frame(sys.parent()))
   missing.subset <- is.null(subset)
+  ##
+  exclude <- eval(mf[[match("exclude", names(mf))]],
+                  data, enclos = sys.frame(sys.parent()))
+  missing.exclude <- is.null(exclude)
   
   
   ##
@@ -127,14 +131,26 @@ metacor <- function(cor, n, studlab,
   
   ##
   ##
-  ## (4) Subset and subgroups
+  ## (4) Subset, exclude studies, and subgroups
   ##
   ##
   if (!missing.subset)
     if ((is.logical(subset) & (sum(subset) > k.All)) ||
         (length(subset) > k.All))
       stop("Length of subset is larger than number of studies.")
-  ##  
+  ##
+  if (!missing.exclude) {
+    if ((is.logical(exclude) & (sum(exclude) > k.All)) ||
+        (length(exclude) > k.All))
+      stop("Length of argument 'exclude' is larger than number of studies.")
+    ##
+    exclude2 <- rep(FALSE, k.All)
+    exclude2[exclude] <- TRUE
+    exclude <- exclude2
+  }
+  else
+    exclude <- rep(FALSE, k.All)
+  ##
   if (!missing.byvar) {
     chkmiss(byvar)
     byvar.name <- byvarname(mf[[match("byvar", names(mf))]])
@@ -168,6 +184,9 @@ metacor <- function(cor, n, studlab,
         data$.subset[subset] <- TRUE
       }
     }
+    ##
+    if (!missing.exclude)
+      data$.exclude <- exclude
   }
   
   
@@ -181,6 +200,8 @@ metacor <- function(cor, n, studlab,
     n   <- n[subset]
     studlab <- studlab[subset]
     ##
+    exclude <- exclude[subset]
+    ##
     if (!missing.byvar)
       byvar <- byvar[subset]
   }
@@ -229,6 +250,7 @@ metacor <- function(cor, n, studlab,
   ##
   ##
   m <- metagen(TE, seTE, studlab,
+               exclude = if (missing.exclude) NULL else exclude,
                ##
                sm = sm,
                level = level,
