@@ -88,6 +88,13 @@ metainf <- function(x, pooled, sortvar) {
   studlab <- x$studlab[o]
   slab <- c(paste("Omitting", studlab), "Pooled estimate")
   studlab <- c(rev(rev(slab)[-1]), " ", rev(slab)[1])
+  ##
+  ## Exclude studies from meta-analysis
+  ##
+  if (!is.null(x$exclude))
+    exclude <- x$exclude[o]
+  else
+    exclude <- rep_len(FALSE, k.all)
   
   
   ##
@@ -107,6 +114,8 @@ metainf <- function(x, pooled, sortvar) {
     ##
     if (inherits(x, "metabin"))
       m <- metabin(event.e[sel], n.e[sel], event.c[sel], n.c[sel],
+                   ##
+                   exclude = exclude[sel],
                    ##
                    method = x$method, sm = x$sm,
                    incr = incr.i, allincr = x$allincr, addincr = x$addincr,
@@ -126,6 +135,8 @@ metainf <- function(x, pooled, sortvar) {
       m <- metacont(n.e[sel], mean.e[sel], sd.e[sel],
                     n.c[sel], mean.c[sel], sd.c[sel],
                     ##
+                    exclude = exclude[sel],
+                    ##
                     sm = x$sm, pooledvar = x$pooledvar,
                     ##
                     level.comb = x$level.comb,
@@ -139,8 +150,11 @@ metainf <- function(x, pooled, sortvar) {
     ##
     if (inherits(x, "metacor"))
       m <- metacor(cor[sel], n[sel],
+                   ##
+                   exclude = exclude[sel],
                    ##
                    sm = x$sm,
+                   null.effect = x$null.effect,
                    ##
                    level.comb = x$level.comb,
                    ##
@@ -152,8 +166,11 @@ metainf <- function(x, pooled, sortvar) {
     ##
     if (inherits(x, "metagen"))
       m <- metagen(TE[sel], seTE[sel],
+                   ##
+                   exclude = exclude[sel],
                    ##
                    sm = x$sm,
+                   null.effect = x$null.effect,
                    ##
                    level.comb = x$level.comb,
                    ##
@@ -168,6 +185,8 @@ metainf <- function(x, pooled, sortvar) {
       m <- metainc(event.e[sel], time.e[sel],
                    event.c[sel], time.c[sel],
                    ##
+                   exclude = exclude[sel],
+                   ##
                    method = x$method,
                    sm = x$sm,
                    incr = incr.i, allincr = x$allincr, addincr = x$addincr,
@@ -182,8 +201,12 @@ metainf <- function(x, pooled, sortvar) {
     ##
     if (inherits(x, "metaprop"))
       m <- metaprop(event[sel], n[sel],
+                    ##
+                    exclude = exclude[sel],
                     ##
                     sm = x$sm,
+                    null.effect = x$null.effect,
+                    ##
                     incr = incr.i, allincr = x$allincr, addincr = x$addincr,
                     method.ci = x$method.ci,
                     ##
@@ -198,8 +221,12 @@ metainf <- function(x, pooled, sortvar) {
     ##
     if (inherits(x, "metarate"))
       m <- metarate(event[sel], time[sel],
+                    ##
+                    exclude = exclude[sel],
                     ##
                     sm = x$sm,
+                    null.effect = x$null.effect,
+                    ##
                     incr = incr.i, allincr = x$allincr, addincr = x$addincr,
                     ##
                     level.comb = x$level.comb,
