@@ -1,6 +1,7 @@
 metaprop <- function(event, n, studlab,
                      ##
-                     data = NULL, subset = NULL, method = "Inverse",
+                     data = NULL, subset = NULL, exclude = NULL,
+                     method = "Inverse",
                      ##
                      sm = gs("smprop"),
                      ##
@@ -113,7 +114,7 @@ metaprop <- function(event, n, studlab,
   ##
   mf <- match.call()
   ##
-  ## Catch event, n from data:
+  ## Catch 'event' and 'n' from data:
   ##
   event <- eval(mf[[match("event", names(mf))]],
                 data, enclos = sys.frame(sys.parent()))
@@ -124,14 +125,14 @@ metaprop <- function(event, n, studlab,
             data, enclos = sys.frame(sys.parent()))
   chknull(n)
   ##
-  ## Catch incr from data:
+  ## Catch 'incr' from data:
   ##
   if (!missing(incr))
     incr <- eval(mf[[match("incr", names(mf))]],
                  data, enclos = sys.frame(sys.parent()))
   chknumeric(incr, min = 0)
   ##
-  ## Catch studlab, byvar, subset from data:
+  ## Catch 'studlab', 'byvar', 'subset', and 'exclude' from data:
   ##
   studlab <- eval(mf[[match("studlab", names(mf))]],
                   data, enclos = sys.frame(sys.parent()))
@@ -149,6 +150,10 @@ metaprop <- function(event, n, studlab,
   subset <- eval(mf[[match("subset", names(mf))]],
                  data, enclos = sys.frame(sys.parent()))
   missing.subset <- is.null(subset)
+  ##
+  exclude <- eval(mf[[match("exclude", names(mf))]],
+                  data, enclos = sys.frame(sys.parent()))
+  missing.exclude <- is.null(exclude)
   
   
   ##
@@ -197,13 +202,25 @@ metaprop <- function(event, n, studlab,
   
   ##
   ##
-  ## (4) Subset and subgroups
+  ## (4) Subset, exclude studies, and subgroups
   ##
   ##
   if (!missing.subset)
     if ((is.logical(subset) & (sum(subset) > k.All)) ||
         (length(subset) > k.All))
       stop("Length of subset is larger than number of studies.")
+  ##
+  if (!missing.exclude) {
+    if ((is.logical(exclude) & (sum(exclude) > k.All)) ||
+        (length(exclude) > k.All))
+      stop("Length of argument 'exclude' is larger than number of studies.")
+    ##
+    exclude2 <- rep(FALSE, k.All)
+    exclude2[exclude] <- TRUE
+    exclude <- exclude2
+  }
+  else
+    exclude <- rep(FALSE, k.All)
   ##  
   if (!missing.byvar) {
     chkmiss(byvar)
@@ -240,6 +257,9 @@ metaprop <- function(event, n, studlab,
         data$.subset[subset] <- TRUE
       }
     }
+    ##
+    if (!missing.exclude)
+      data$.exclude <- exclude
   }
   
   
@@ -253,6 +273,8 @@ metaprop <- function(event, n, studlab,
     n   <- n[subset]
     studlab <- studlab[subset]
     ##
+    exclude <- exclude[subset]
+    ##
     if (length(incr) > 1)
       incr <- incr[subset]
     ##
@@ -433,7 +455,7 @@ metaprop <- function(event, n, studlab,
   ##
   ##
   if (method == "GLMM") {
-    glmm.fixed <- metafor::rma.glmm(xi = event, ni = n,
+    glmm.fixed <- metafor::rma.glmm(xi = event[!exclude], ni = n[!exclude],
                                     method = "FE",
                                     test = ifelse(hakn, "t", "z"),
                                     level = 100 * level.comb,
@@ -447,6 +469,7 @@ metaprop <- function(event, n, studlab,
   }
   ##
   m <- metagen(TE, seTE, studlab,
+               exclude = if (missing.exclude) NULL else exclude,
                ##
                sm = sm,
                level = level,
@@ -524,7 +547,7 @@ metaprop <- function(event, n, studlab,
     res$zval.fixed <- ci.f$z
     res$pval.fixed <- ci.f$p
     ##
-    glmm.random <- metafor::rma.glmm(xi = event, ni = n,
+    glmm.random <- metafor::rma.glmm(xi = event[!exclude], ni = n[!exclude],
                                      method = method.tau,
                                      test = ifelse(hakn, "t", "z"),
                                      level = 100 * level.comb,
